@@ -12,7 +12,7 @@
 from __future__ import with_statement
 from Cookie import SimpleCookie
 from datetime import datetime
-from flask import _request_ctx_stack as stack, Config, Flask, g, json
+from flask import _request_ctx_stack as stack, Config, Flask, g
 from functools import wraps
 from httplib import BadStatusLine
 from re import match
@@ -23,6 +23,11 @@ from zlib import compress
 import os
 import sys
 
+try:
+    from flask.json import _json as json
+except ImportError:
+    from flask import json
+
 try:
     import pkg_resources
 except ImportError:
